==> client-sdk-react-1.0.0.tgz: package/src/components/Chat/ChatMessage/ChatMessageWithAvatar.tsx <==
import React from 'react'
import classNames from 'classnames'
import Linkify from 'linkify-react'
import { ChatMessageElementProps } from '../models'
import { useZocksStore } from '../../../app'
import { selectLocalParticipant } from '../../../store'
import { ChatMessageAttachment } from './ChatMessageAttachment'
import './ChatMessageWithAvatar.scss'

const linkifyOptions = {
  defaultProtocol: 'https',
  target: '_blank',
}

interface AvatarProps {
  showAvatar: boolean
}

export const ChatMessageWithAvatar: React.FC<ChatMessageElementProps & AvatarProps> = ({
  chatMessage,
  getAttachmentLocation,
  showAvatar,
  chatMessageAttachmentElement,
}) => {
  const { id: localParticipantId } = useZocksStore(selectLocalParticipant)
  const {
    from: { id: senderId, name: senderName },
    message,
    attachment,
  } = chatMessage

  const sentByMe = senderId === localParticipantId

  const ChatMessageAttachmentElement = chatMessageAttachmentElement ?? ChatMessageAttachment

  return (
    <div
      className={classNames('chat-message-a__container', {
        'chat-message-a__container--sent': sentByMe,
        'chat-message-a__container--received': !sentByMe,
      })}
    >
      {showAvatar && <div className='chat-message-a__avatar'>{senderName.slice(0, 1)}</div>}
      <div
        className={classNames('chat-message-a__message-container', {
          'chat-message-a--indent-sent': !showAvatar && sentByMe,
          'chat-message-a--indent-received': !showAvatar && !sentByMe,
        })}
      >
        {message && (
          <Linkify options={linkifyOptions}>
            <div className='chat-message-a__message'>{message}</div>
          </Linkify>
        )}
        {attachment && getAttachmentLocation && (
          <ChatMessageAttachmentElement attachment={attachment} getAttachmentLocation={getAttachmentLocation} />
        )}
      </div>
    </div>
  )
}

==> client-sdk-react-1.13.0.tgz: package/src/components/Chat/ChatMessage/ChatMessageWithAvatar.tsx <==
import React from 'react'
import classNames from 'classnames'
import Linkify from 'linkify-react'
import { ChatMessageElementProps } from '../models'
import { useZocksStore } from '../../../app'
import { selectLocalParticipant } from '../../../store'
import { ChatMessageAttachment } from './ChatMessageAttachment'
import './ChatMessageWithAvatar.scss'

const linkifyOptions = {
  defaultProtocol: 'https',
  target: '_blank',
}

interface AvatarProps {
  showAvatar: boolean
}

export const ChatMessageWithAvatar: React.FC<ChatMessageElementProps & AvatarProps> = ({
  chatMessage,
  getAttachmentLocation,
  showAvatar,
  chatMessageAttachmentElement,
}) => {
  const { id: localParticipantId } = useZocksStore(selectLocalParticipant)
  const {
    from: { id: senderId, name: senderName },
    message,
    attachment,
  } = chatMessage

  const sentByMe = senderId === localParticipantId

  const ChatMessageAttachmentElement = chatMessageAttachmentElement ?? ChatMessageAttachment

  return (
    <div
      className={classNames('chat-message-a__container', {
        'chat-message-a__container--sent': sentByMe,
        'chat-message-a__container--received': !sentByMe,
      })}
    >
      {showAvatar && <div className='chat-message-a__avatar' title={senderName}>{senderName.slice(0, 1)}</div>}
      <div
        className={classNames('chat-message-a__message-container', {
          'chat-message-a--indent-sent': !showAvatar && sentByMe,
          'chat-message-a--indent-received': !showAvatar && !sentByMe,
        })}
      >
        {message && (
          <Linkify options={linkifyOptions}>
            <div className='chat-message-a__message'>{message}</div>
          </Linkify>
        )}
        {attachment && getAttachmentLocation && (
          <ChatMessageAttachmentElement attachment={attachment} getAttachmentLocation={getAttachmentLocation} />
        )}
      </div>
    </div>
  )
}
